@@ -25,7 +25,7 @@
  */
 
 // standard wx include
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 
 // standard hugin include
@@ -47,13 +47,6 @@
 
 #include "vigra_ext/ImageTransforms.h"
 
-#if !wxCHECK_VERSION(3,0,0)
-#define wxPENSTYLE_SOLID wxSOLID
-#define wxPENSTYLE_DOT wxDOT
-#define wxBRUSHSTYLE_TRANSPARENT wxTRANSPARENT
-#define wxBRUSHSTYLE_SOLID wxSOLID
-#endif
-
 // definition of the control point event
 
 IMPLEMENT_DYNAMIC_CLASS( CPEvent, wxEvent )
@@ -70,6 +63,13 @@ CPEvent::CPEvent( )
     mode = NONE;
 }
 
+CPEvent::CPEvent(wxWindow * win, CPEventMode evt_mode)
+{
+    SetEventType(EVT_CPEVENT);
+    SetEventObject(win);
+    mode = evt_mode;
+}
+
 CPEvent::CPEvent(wxWindow* win, hugin_utils::FDiff2D & p)
 {
     SetEventType( EVT_CPEVENT );
@@ -1571,11 +1571,16 @@ void CPImageCtrl::OnKey(wxKeyEvent & e)
             update();
         }
 
-    } else if (e.m_keyCode == 'a') {
+    }
+    else if (e.m_keyCode == 'a') {
         DEBUG_DEBUG("adding point with a key, faking right click");
         // faking right mouse button with "a"
         // set right up event
-        CPEvent ev(this, CPEvent::RIGHT_CLICK, hugin_utils::FDiff2D(0,0));
+        CPEvent ev(this, CPEvent::RIGHT_CLICK, hugin_utils::FDiff2D(0, 0));
+        emit(ev);
+    }
+    else if (e.m_keyCode==WXK_ESCAPE) {
+        CPEvent ev(this, CPEvent::CANCELED);
         emit(ev);
     } else {
         // forward some keys...
@@ -1737,11 +1742,7 @@ void CPImageCtrl::ScrollDelta(const wxPoint & delta)
 
 const wxSize CPImageCtrl::GetBitmapSize() const
 {
-#if wxCHECK_VERSION(2,9,0)
     return bitmap.GetSize();
-#else
-    return wxSize(bitmap.GetWidth(), bitmap.GetHeight());
-#endif
 };
 
 IMPLEMENT_DYNAMIC_CLASS(CPImageCtrl, wxScrolledWindow)
